==> bRacatus_1.0.0.tar.gz: bRacatus/R/bRacatus-package.R <==
#'Cell ID raster
#'
#'  A \code{Raster} half-degree raster of the world with unique IDs per cell
#'
#' @name ID_raster
#' @docType data
#' @keywords reference
#' @examples
#' 
#' data("ID_raster")
#' 
NULL

#'Hemitriccus mirandae spatialPoints exemplary file
#'
#'  A \code{SpatialPointsDataFrame} containing the occurrences of 
#'  Hemitriccus mirandae downloaded from GBIF
#'
#' @name H_mirandae_sp
#' @docType data
#' @keywords examplary object
#' @examples
#' 
#' data("H_mirandae_sp")
#' 
NULL

#'Accuracy model
#'
#'  A \code{glm} accuracy model
#'
#' @name Model_accuracy
#' @docType data
#' @keywords model object
#' @examples
#' 
#' data("Model_accuracy")
#' 
NULL

#'Biogeographical model
#'
#'  A \code{glm} biogeographical model
#'
#' @name Model_biogeo
#' @docType data
#' @keywords model object
#' @examples
#' 
#' data("Model_biogeo")
#' 
NULL

#'Range Phalanger orientalis
#'
#'  A \code{SpatialPolygonsDataFrame} Range Phalanger orientalis
#'
#' @name Range_Phalanger_orientalis
#' @docType data
#' @keywords examplary object
#' @examples
#' 
#' data("Range_Phalanger_orientalis")
#' 
NULL

#'signals example 1
#'
#'  A \code{SpatialPolygonsDataFrame} signals example 1
#'
#' @name signals
#' @docType data
#' @keywords examplary object
#' @examples
#' 
#' data("signals")
#' 
NULL

#'signals example 2
#'
#'  A \code{SpatialPolygonsDataFrame} signals example 2
#'
#' @name signals_2
#' @docType data
#' @keywords examplary object
#' @examples
#' 
#' data("signals_2")
#' 
NULL

#'signals example 3
#'
#'  A \code{SpatialPolygonsDataFrame} signals example 3
#'
#' @name signals_3
#' @docType data
#' @keywords examplary object
#' @examples
#' 
#' data("signals_3")
#' 
NULL

==> bRacatus_2.0.0.tar.gz: bRacatus/R/bRacatus-package.R <==
#'Cell ID raster
#'
#'  A \code{Raster} half-degree raster of the world with unique IDs per cell
#'
#' @name ID_raster
#' @docType data
#' @keywords reference
#' @examples
#' 
#' data("ID_raster")
#' 
NULL

#'Hemitriccus mirandae spatialPoints exemplary file
#'
#'  A \code{SpatialPointsDataFrame} containing the occurrences of 
#'  Hemitriccus mirandae downloaded from GBIF
#'
#' @name H_mirandae_sp
#' @docType data
#' @keywords examplary object
#' @examples
#' 
#' data("H_mirandae_sp")
#' 
NULL

#'Accuracy model
#'
#'  A \code{glm} accuracy model
#'
#' @name Model_accuracy
#' @docType data
#' @keywords model object
#' @examples
#' 
#' data("Model_accuracy")
#' 
NULL

#'Biogeographical model
#'
#'  A \code{glm} biogeographical model
#'
#' @name Model_biogeo
#' @docType data
#' @keywords model object
#' @examples
#' 
#' data("Model_biogeo")
#' 
NULL

#'Range Phalanger orientalis
#'
#'  A \code{SpatialPolygonsDataFrame} Range Phalanger orientalis
#'
#' @name Range_Phalanger_orientalis
#' @docType data
#' @keywords examplary object
#' @examples
#' 
#' data("Range_Phalanger_orientalis")
#' 
NULL

#'signals example 1
#'
#'  A \code{SpatialPolygonsDataFrame} signals example 1
#'
#' @name signals
#' @docType data
#' @keywords examplary object
#' @examples
#' 
#' data("signals")
#' 
NULL

#'signals example 2
#'
#'  A \code{SpatialPolygonsDataFrame} signals example 2
#'
#' @name signals_2
#' @docType data
#' @keywords examplary object
#' @examples
#' 
#' data("signals_2")
#' 
NULL

#'signals example 3
#'
#'  A \code{SpatialPolygonsDataFrame} signals example 3
#'
#' @name signals_3
#' @docType data
#' @keywords examplary object
#' @examples
#' 
#' data("signals_3")
#' 
NULL

#'pts example 1
#'
#'  A \code{DataFrame} pts example 1
#'
#' @name pts
#' @docType data
#' @keywords examplary object
#' @examples
#' 
#' data("pts")
#' 
NULL

#'pts example 2
#'
#'  A \code{DataFrame} pts example 2
#'
#' @name pts2
#' @docType data
#' @keywords examplary object
#' @examples
#' 
#' data("pts2")
#' 
NULL
